@@ -17,7 +17,7 @@ use 5.000;
 @EXPORT = qw(
 	
 );
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 
 # Preloaded methods go here.
@@ -41,6 +41,11 @@ sub tell {
     ${*$fh}->TELL( @_ );
 }
 
+sub mem {
+    my $fh = shift;
+    ${*$fh}->{mem};
+}
+
 sub doclose {
     my $fh = shift;
     untie *$fh;
